@@ -1038,11 +1038,13 @@ def runtestswithappsurify(*args):
     #cypress
     #https://github.com/bahmutov/cypress-select-tests
     #cypress run --reporter junit --reporter-options mochaFile=result.xml
+    #updated to https://github.com/cypress-io/cypress-grep
     if testtemplate == "cypress":
-        testseparator="|"
+        testseparator="; "
         reporttype="file"
         report="results.xml"
-        startrunspecific="cypress run --reporter junit --reporter-options mochaFile=result.xml grep="
+        startrunspecific="cypress run --reporter junit --reporter-options mochaFile=result.xml grep=\""
+        endrunspecific="\""
         postfixtest="'"
         prefixtest="'"
         startrunall="cypress run --reporter junit --reporter-options mochaFile=result.xml"
